Test Data Generation
============================

.. contents::
    :depth: 2
    :local:

Random Keys
------------------------

.. currentmodule:: cr.nimble

.. autosummary::
    :toctree: _autosummary

    KEY0
    KEYS


Random Subspaces
------------------------

.. currentmodule:: cr.nimble.data

.. autosummary::
    :toctree: _autosummary

    random_subspaces
    random_subspaces_jit
    uniform_points_on_subspaces
    uniform_points_on_subspaces_jit
    two_subspaces_at_angle
    two_subspaces_at_angle_jit
    three_subspaces_at_angle
    three_subspaces_at_angle_jit
